@@ -1,10 +1,10 @@
-package common::header v0.1.6;
+package common::header v0.2.0;
 
 # NOTE !!!WARNING!!! don't use indirect with strawberry perl
 # https://rt.cpan.org/Public/Bug/Display.html?id=102321
 
 use utf8;
-use strict qw[refs subs vars];
+use strict qw[subs vars];
 
 no warnings;    ## no critic qw[TestingAndDebugging::ProhibitNoWarnings]
 use warnings (
